---
pagetitle: simple
toc-title: Table of contents
---

# Hello

Here is some text

``` python
print("Hello World")

import warnings

warnings.warn("This is a warning")

raise NotImplementedError
```

    Hello World

    /var/folders/5j/x2qvf77j1m7736lccs2xt6c40000gn/T/ipykernel_10621/3924225401.py:5: UserWarning: This is a warning
      warnings.warn("This is a warning")

    NotImplementedError: 

Some other text

``` python
print("Hello World2")

import warnings

warnings.warn("This is a warning")

raise NotImplementedError
```

    Hello World2

    /var/folders/5j/x2qvf77j1m7736lccs2xt6c40000gn/T/ipykernel_10621/3538506256.py:5: UserWarning: This is a warning
      warnings.warn("This is a warning")

    NotImplementedError: 
